==> gnuradio-core-2.0.tar.gz: gnuradio-core-2.0/src/lib/swig/gnuradio_swig_bug_workaround.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H
#define INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H

/*
 * This include files works around a bug in SWIG 1.3.21
 * where it fails to emit these declarations when doing
 * %import "gnuradio.i"
 */

class gr_add_cc;
class gr_add_const_cc;
class gr_add_const_ff;
class gr_add_const_ii;
class gr_add_const_sf;
class gr_add_const_ss;
class gr_add_ff;
class gr_add_ii;
class gr_add_ss;
class gr_audio_sink_oss;
class gr_block;
class gr_divide_cc;
class gr_divide_ff;
class gr_divide_ii;
class gr_divide_ss;
class gr_file_sink;
class gr_file_source;
class gr_fir_filter_ccc;
class gr_fir_filter_ccf;
class gr_fir_filter_fcc;
class gr_fir_filter_fff;
class gr_fir_filter_fsf;
class gr_fir_filter_scc;
class gr_float_to_complex;
class gr_freq_xlating_fir_filter_ccc;
class gr_freq_xlating_fir_filter_ccf;
class gr_freq_xlating_fir_filter_fcc;
class gr_freq_xlating_fir_filter_fcf;
class gr_freq_xlating_fir_filter_scc;
class gr_freq_xlating_fir_filter_scf;
class gr_head;
class gr_multiply_cc;
class gr_multiply_const_cc;
class gr_multiply_const_ff;
class gr_multiply_const_ii;
class gr_multiply_const_ss;
class gr_multiply_ff;
class gr_multiply_ii;
class gr_multiply_ss;
class gr_noise_source_c;
class gr_noise_source_f;
class gr_noise_source_i;
class gr_noise_source_s;
class gr_nop;
class gr_null_sink;
class gr_null_source;
class gr_quadrature_demod_cf;
class gr_sig_source_c;
class gr_sig_source_f;
class gr_sig_source_i;
class gr_sig_source_s;
class gr_sub_cc;
class gr_sub_ff;
class gr_sub_ii;
class gr_sub_ss;
class gr_sync_block;
class gr_sync_decimator;
class gr_sync_interpolator;
class gr_vector_sink_c;
class gr_vector_sink_f;
class gr_vector_sink_i;
class gr_vector_sink_s;
class gr_vector_source_c;
class gr_vector_source_f;
class gr_vector_source_i;
class gr_vector_source_s;
class usrp_sink_c;

#endif /* INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H */

==> gnuradio-core-2.2.tar.gz: gnuradio-core-2.2/src/lib/swig/gnuradio_swig_bug_workaround.h <==
/* -*- c++ -*- */
/*
 * Copyright 2004 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H
#define INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H

/*
 * This include files works around a bug in SWIG 1.3.21 and 22
 * where it fails to emit these declarations when doing
 * %import "gnuradio.i"
 */

class gr_add_cc;
class gr_add_const_cc;
class gr_add_const_ff;
class gr_add_const_ii;
class gr_add_const_sf;
class gr_add_const_ss;
class gr_add_ff;
class gr_add_ii;
class gr_add_ss;
class gr_block;
class gr_bytes_to_syms;
class gr_check_counting_s;
class gr_check_lfsr_32k_s;
class gr_complex_to_arg;
class gr_complex_to_float;
class gr_complex_to_imag;
class gr_complex_to_mag;
class gr_complex_to_real;
class gr_divide_cc;
class gr_divide_ff;
class gr_divide_ii;
class gr_divide_ss;
class gr_fft_vcc;
class gr_fft_vfc;
class gr_file_descriptor_sink;
class gr_file_descriptor_source;
class gr_file_sink;
class gr_file_source;
class gr_fir_filter_ccc;
class gr_fir_filter_ccf;
class gr_fir_filter_fcc;
class gr_fir_filter_fff;
class gr_fir_filter_fsf;
class gr_fir_filter_scc;
class gr_float_to_complex;
class gr_float_to_short;
class gr_freq_xlating_fir_filter_ccc;
class gr_freq_xlating_fir_filter_ccf;
class gr_freq_xlating_fir_filter_fcc;
class gr_freq_xlating_fir_filter_fcf;
class gr_freq_xlating_fir_filter_scc;
class gr_freq_xlating_fir_filter_scf;
class gr_frequency_modulator_fc;
class gr_head;
class gr_iir_filter_ffd;
class gr_interp_fir_filter_ccc;
class gr_interp_fir_filter_ccf;
class gr_interp_fir_filter_fcc;
class gr_interp_fir_filter_fff;
class gr_interp_fir_filter_fsf;
class gr_interp_fir_filter_scc;
class gr_keep_one_in_n;
class gr_lfsr_32k_source_s;
class gr_multiply_cc;
class gr_multiply_const_cc;
class gr_multiply_const_ff;
class gr_multiply_const_ii;
class gr_multiply_const_ss;
class gr_multiply_ff;
class gr_multiply_ii;
class gr_multiply_ss;
class gr_noise_source_c;
class gr_noise_source_f;
class gr_noise_source_i;
class gr_noise_source_s;
class gr_nop;
class gr_null_sink;
class gr_null_source;
class gr_oscope_sink_f;
class gr_oscope_sink_x;
class gr_quadrature_demod_cf;
class gr_serial_to_parallel;
class gr_short_to_float;
class gr_sig_source_c;
class gr_sig_source_f;
class gr_sig_source_i;
class gr_sig_source_s;
class gr_simple_correlator;
class gr_simple_framer;
class gr_sub_cc;
class gr_sub_ff;
class gr_sub_ii;
class gr_sub_ss;
class gr_sync_block;
class gr_sync_decimator;
class gr_sync_interpolator;
class gr_vector_sink_b;
class gr_vector_sink_c;
class gr_vector_sink_f;
class gr_vector_sink_i;
class gr_vector_sink_s;
class gr_vector_source_b;
class gr_vector_source_c;
class gr_vector_source_f;
class gr_vector_source_i;
class gr_vector_source_s;
class microtune_4702_eval_board;
class microtune_4937_eval_board;
class microtune_xxxx_eval_board;

#endif /* INCLUDED_GNURADIO_SWIG_BUG_WORKAROUND_H */
